<?xml version='1.0'?>
<!--########################################################################### 
 |    $Id: mediaobject.mod.xsl,v 1.5 2001/08/24 23:47:55 ben Exp $
 |- ###########################################################################
 |   $Author: ben $
 |
 |   This file comes from the DB2LaTeX XSLT Stylesheets by Ramon Casellas who
 |   accepted its reuse and customization for this package.
 |                                                        
 |   PURPOSE: Manage Imageobject related tags.
 + ############################################################################ -->

<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
    exclude-result-prefixes="doc" version='1.0'>


<xsl:template match="videoobject">
  <xsl:apply-templates select="videodata"/>
</xsl:template>

<xsl:template match="audioobject">
  <xsl:apply-templates select="audiodata"/>
</xsl:template>

<xsl:template match="textobject">
  <xsl:apply-templates/>
</xsl:template>


<doc:template name="mediaobject" id="unsupported" xmlns="">
  <refpurpose>Figure inclusion</refpurpose>
  <refdescription>
    <para>This element translated only for figure file inclusion. The following
    example is well translated:</para>
<programlisting>
<![CDATA[<figure float="0" id="figureeps"> 
  <title>A pdf/eps fig </title> 
  <mediaobject> 
    <imageobject> 
      <imagedata fileref="figures/sample" align="center" scale="75"> 
      </imagedata> 
    </imageobject> 
    <textobject> 
      <para> figure Description </para> 
    </textobject> 
  </mediaobject> 
</figure>]]>
</programlisting>
  <para>The question is: how should be translated the other media?</para>
  </refdescription>
</doc:template>


<xsl:template match="mediaobject">
<xsl:variable name="imageobjectscnt" select="count(child::imageobject)"/>
<xsl:choose>
  <xsl:when test="$imageobjectscnt > 1">
    <xsl:text>\mbox {&#10;</xsl:text>
    <xsl:apply-templates select="imageobject"/>
    <xsl:text>}&#10;</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="imageobject"/>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template match="inlinemediaobject">
<xsl:variable name="imageobjectscnt" select="count(child::imageobject)"/>
<xsl:choose>
  <xsl:when test="$imageobjectscnt > 1">
    <xsl:text>\mbox {&#10;</xsl:text>
    <xsl:apply-templates select="imageobject"/>
    <xsl:text>}&#10;</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="imageobject"/>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template match="imageobject">
  <xsl:apply-templates select="imagedata"/>
</xsl:template>


<xsl:template match="imagedata">
<xsl:variable name="filename" select="@fileref"/>
<xsl:variable name="ext">
  <xsl:call-template name="filename-extension">
  <xsl:with-param name="filename" select="$filename"/>
  </xsl:call-template>
</xsl:variable>

<xsl:if test="count(../../imageobject) &gt; 1">
  <xsl:text>\subfigure[</xsl:text>
  <xsl:value-of select="../@role"/><xsl:text>]</xsl:text>
</xsl:if>

<xsl:text>\begin_inset Figure size 100 100&#10;</xsl:text>
<xsl:text>file </xsl:text><xsl:value-of select="normalize-space(@fileref)"/>

<xsl:choose>
  <xsl:when test="@scale"> 
    <xsl:text>&#10;width 3 </xsl:text>
    <xsl:value-of select="normalize-space(@scale)"/>
  </xsl:when>
</xsl:choose>

<xsl:text>&#10;flags 9&#10;\end_inset&#10;</xsl:text>

<xsl:choose>
  <xsl:when test="@format = 'PRN'"><xsl:text>, angle=270</xsl:text></xsl:when>
</xsl:choose>
</xsl:template>


<xsl:template match="videodata">
  <xsl:variable name="filename">
    <xsl:call-template name="mediaobject.filename">
      <xsl:with-param name="object" select=".."/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="alt">
    <xsl:apply-templates select="(../../textobject/phrase)[1]"/>
  </xsl:variable>
</xsl:template>


<xsl:template match="audiodata">
  <xsl:variable name="filename">
    <xsl:call-template name="mediaobject.filename">
      <xsl:with-param name="object" select=".."/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="alt">
    <xsl:apply-templates select="(../../textobject/phrase)[1]"/>
  </xsl:variable>
</xsl:template>


<xsl:template match="caption">
  <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>
