<?xml version='1.0'?>
<!--########################################################################### 
 |    $Id: unsupported.mod.xsl,v 1.4 2001/05/09 18:53:34 ben Exp $        
 |- ###########################################################################
 |   $Author: ben $
 |
 |   PURPOSE: Generic procedure to translate elements that are not directly
 |            supported by LyX.
 |
 + ############################################################################ -->
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
    exclude-result-prefixes="doc" version='1.0'>

<doc:reference id="unsupported" xmlns="">
  <referenceinfo>
  <releaseinfo role="meta">
     $Id: unsupported.mod.xsl,v 1.4 2001/05/09 18:53:34 ben Exp $
  </releaseinfo>
  <author>
    <surname>Guillon</surname>
    <firstname>Benoit</firstname>
  </author>
  <copyright><year>2001</year>
    <holder>Benoit Guillon</holder>
  </copyright>
  </referenceinfo>

  <title>Unsupported DocBook Elements</title>

  <partintro>
  <section><title>Introduction</title>

  <para>Some of the DocBook elements are not directly supported by LyX,
  since the LyX file format is more limited and/or contains different kind of
  information.</para>

  <para>If the DocBook to LyX translation was only a process to publish a
  document it would not be a real problem, since at this level only the
  rendering purpose is important: for each element or element combinations a
  rendering choice can be taken. The initial document structure is then lost,
  but it is out of scope of the process.</para>

  <para>The problem is that translating to LyX is translating from one structure
  to another. Thus structure or information is important and should not be lost.
  The DocBook to LyX translation should allow to translate back
  to XML without losing too much information.
  Besides, rendering is important too, since LyX display the document
  in a WYSIWYM way.</para>

  <para>So, the strategy used to translate unsupported elements follows one of
  these cases:</para>
  <itemizedlist>
  <listitem><para>
  The element is related to a similar LyX feature, but some of its information
  has no meaning in LyX. In this case the additionnal information is silently
  lost.
  </para></listitem>
  <listitem><para>
  The element does not exist, but can be emulated to something else that
  respects the original principles and/or the default rendering.
  </para></listitem>
  <listitem><para>
  The element does not exist, and trying to replace it by something else can
  involve a loss of information. The element is then copied as is by using
  the SGML Style (unsupported blocks) or ERT (unsupported inlined elements).
  </para></listitem>
  </itemizedlist>

  <para>
  Of course, different methods can be applied to translate the same element,
  and selecting one method depends on some considerations discussed for each
  element.
  This reference lists all the unsupported elements translated to "something",
  and the reason of the translation choice.</para>

  <note>The elements listed here are about the features not basically supported
  by LyX. The elements that are not translated by the package due to
  missing things or bugs are not listed here because they are probably not
  known!</note>

  </section>
  </partintro>
</doc:reference>


<!-- Basically, undefined elements are directly printed as is. The element
     begin and end dislay the element tags. -->

<xsl:template match="@*" mode="attr.copy">
    <xsl:text> </xsl:text>
    <xsl:value-of select="name()"/>
    <xsl:text>="</xsl:text>
    <xsl:value-of select="."/>
    <xsl:text>"</xsl:text>
</xsl:template>

<xsl:template name="element.begin">
  <xsl:text>&lt;</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:apply-templates select="@*" mode="attr.copy"/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>

<xsl:template name="element.end">
  <xsl:text>&lt;/</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>


<!-- Method to include undefined inlined elements, with ERT.
     Note that the \latex commands should be terminated by a \n. Unfortunately
     if we do so the ragged.left funcion removes some expected spaces.
-->

<xsl:template name="unsupported.inline">
  <xsl:message>***Warning: element &lt;<xsl:value-of select="name()"/>&gt; not translated</xsl:message>
  <xsl:param name="content">
    <xsl:apply-templates/>
  </xsl:param>
  <xsl:text>&#10;\latex latex </xsl:text>
  <xsl:call-template name="element.begin"/>
  <xsl:text>&#10;\latex default </xsl:text>
  
  <xsl:copy-of select="$content"/>
  
  <xsl:text>&#10;\latex latex </xsl:text>
  <xsl:call-template name="element.end"/>
  <xsl:text>&#10;\latex default </xsl:text>
</xsl:template>


<!-- Method to include undefined blocks elements, with SGML layout. -->

<xsl:template name="unsupported.block">
  <xsl:message>***Warning: element &lt;<xsl:value-of select="name()"/>&gt; not translated</xsl:message>
  <xsl:text>&#10;\layout SGML&#10;</xsl:text>
  <xsl:call-template name="element.begin"/>
  <xsl:text>&#10;</xsl:text>

  <xsl:apply-templates/>

  <xsl:text>&#10;\layout SGML&#10;</xsl:text>
  <xsl:call-template name="element.end"/>
  <xsl:text>&#10;</xsl:text>
</xsl:template>

</xsl:stylesheet>
